.. nanoml documentation master file, created by
   sphinx-quickstart on Wed Mar 19 19:39:54 2025.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

nanoml documentation
====================

.. toctree::
   :maxdepth: 10
   :caption: Contents:

   nanoml
   readme_link